REV Libraries
==============

These are not installed on the Robot by default, you need to add this project
to your :doc:`pyproject.toml <frc:docs/software/python/pyproject_toml>`.

This documentation documents the various classes and methods that are
available to Python code, but don't discuss in detail how to actually
set up, configure, and tune your REV hardware. For that kind of information,
refer to the `REVLib site <https://docs.revrobotics.com/docs/first-robotics-competition>`_.

.. toctree::
    
    rev
